@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003-2004 Imendio HB
+ * Copyright (C) 2003-2004 Imendio AB
  * Copyright (C) 2003-2004 Sjoerd Simons <sjoerd@luon.net>
  *
  * This program is free software; you can redistribute it and/or
@@ -258,11 +258,18 @@ connection_new_message_cb (LmParser     *parser,
 			   LmMessage    *m,
 			   LmConnection *connection)
 {
+	const gchar *from;
+	
 	lm_message_ref (m);
 
+	from = lm_message_node_get_attribute (m->node, "from");
+	if (!from) {
+		from = "unknown";
+	}
+	
 	lm_verbose ("New message with type=\"%s\" from: %s\n",
 		    _lm_message_type_to_string (lm_message_get_type (m)),
-		    lm_message_node_get_attribute (m->node, "from"));
+		    from);
 
 	g_queue_push_tail (connection->incoming_messages, m);
 }
@@ -652,15 +659,18 @@ connection_do_close (LmConnection *connection)
 	connection_stop_keep_alive (connection);
 
 	if (connection->io_channel) {
-		g_source_remove (connection->io_watch_in);
-		g_source_remove (connection->io_watch_err);
-		g_source_remove (connection->io_watch_hup);
+		g_source_destroy (g_main_context_find_source_by_id (
+			connection->context, connection->io_watch_in));
+		g_source_destroy (g_main_context_find_source_by_id (
+			connection->context, connection->io_watch_err));
+		g_source_destroy (g_main_context_find_source_by_id (
+			connection->context, connection->io_watch_hup));
 
 		g_io_channel_unref (connection->io_channel);
 		connection->io_channel = NULL;
 	}
 
-	g_source_remove (g_source_get_id (connection->incoming_source));
+	g_source_destroy (connection->incoming_source);
 	g_source_unref (connection->incoming_source);
 
 	if (!lm_connection_is_open (connection)) {
@@ -681,7 +691,7 @@ connection_in_event (GIOChannel   *source,
 		     LmConnection *connection)
 {
 	gchar     buf[IN_BUFFER_SIZE];
-	gint      bytes_read;
+	gsize      bytes_read;
 	GIOStatus status;
        
 	if (!connection->io_channel) {
@@ -1659,15 +1669,13 @@ lm_connection_get_proxy (LmConnection *connection)
  * @connection: an #LmConnection
  * @proxy: an #LmProxy
  *
- * Sets the proxy to use for this connection. To unset pass a proxy of type 
- * #LM_PROXY_TYPE_NONE to this function.
+ * Sets the proxy to use for this connection. To unset pass #NULL.
  * 
  **/
 void
 lm_connection_set_proxy (LmConnection *connection, LmProxy *proxy)
 {
 	g_return_if_fail (connection != NULL);
-	g_return_if_fail (proxy != NULL);
 
 	if (lm_connection_is_open (connection)) {
 		g_warning ("Can't change server proxy while connected");
@@ -1679,7 +1687,7 @@ lm_connection_set_proxy (LmConnection *connection, LmProxy *proxy)
 		connection->proxy = NULL;
 	}
 
-	if (lm_proxy_get_type (proxy) != LM_PROXY_TYPE_NONE) {
+	if (proxy && lm_proxy_get_type (proxy) != LM_PROXY_TYPE_NONE) {
 		connection->proxy = lm_proxy_ref (proxy);
 	}
 }
